@@ -9,9 +9,9 @@ from textwrap import dedent # make sample configuration files more readable.
 from StringIO import StringIO
 from optparse import Values
 
-from weblog.post import Post, PostError
+from weblog.post import Post, PostError, Author
 from weblog.template import environment
-from weblog.publish import load_post_list
+from weblog.publish import load_posts
 from weblog.date import command_date
 from weblog.publish import command_publish
 from weblog import configuration
@@ -19,10 +19,21 @@ from weblog import configuration
 def _file(string):
     return StringIO(dedent(string))
 
+def _default_dict(**kwargs):
+    d = dict(author=Author(''),
+             url='/',
+             encoding='ascii',
+             filesystem_encoding='ascii',
+             ignore_dirs=['templates'],
+             post_per_page=10,
+             feed_limit=10)
+    d.update(kwargs)
+    return d
+
 class TestSimpleLoad(unittest.TestCase):
 
     def test_load_post_list(self):
-        post_list = load_post_list('test/simple/', 'ascii', '')
+        post_list = load_posts('test/simple/', _default_dict())
         self.assertEqual(len(post_list), 3)
         sorted_list = sorted(post_list)
         self.assertEqual(sorted_list[0].title, 'post1')
@@ -30,11 +41,12 @@ class TestSimpleLoad(unittest.TestCase):
         self.assertEqual(sorted_list[2].title, 'post3')
 
     def test_load_post_list_encoding_failure(self):
-        self.assertRaises(PostError, load_post_list, 'test/encoding/', 'ascii',
-                          '')
+        self.assertRaises(PostError, load_posts, 'test/encoding/',
+                          _default_dict())
 
     def test_load_post_list_encoding(self):
-        post_list = load_post_list('test/encoding/', 'UTF-8', '')
+        post_list = load_posts('test/encoding/',
+                               _default_dict(encoding='UTF-8'))
         self.assertEqual(len(post_list), 2)
         sorted_list = sorted(post_list)
         self.assertEqual(sorted_list[0].title,
@@ -78,6 +90,10 @@ class TestPost(unittest.TestCase):
         self.assertEqual(post.encoding, u'utf8')
         self.assertEqual(post.content, u'blah \xdcTF-8.')
 
+    def test_no_title(self):
+        sample = '''No title in this post'''
+        self.assertRaises(PostError, Post, _file(sample))
+
     def test_no_payload(self):
         sample_post = 'title: no payload\ndate: 2008-1-1'
         try:
@@ -251,9 +267,14 @@ class TestConfiguration(unittest.TestCase):
             f.seek(0)
         return f
 
+    _NEEDED_KEYS = ('author', 'url', 'ignore_dirs', 'encoding',
+                    'filesystem_encoding', 'post_per_page', 'feed_limit')
+
     def test_empty(self):
         with self.__config() as f:
-            self.assertEqual(configuration.read(f.name), dict())
+            conf = configuration.read(f.name)
+            self.assert_(isinstance(conf, dict))
+            self.assert_(all(k in conf for k in self._NEEDED_KEYS))
 
     def test_bad_encoding(self):
         with self.__config("encoding = 'DOES NOT EXIST'") as f:
@@ -261,9 +282,11 @@ class TestConfiguration(unittest.TestCase):
 
     def test_encoding(self):
         with self.__config("encoding = 'latin-1'") as f:
-            self.assertEqual(configuration.read(f.name),
-                             dict(encoding='latin-1'))
+            self.assertEqual(configuration.read(f.name)['encoding'], 'latin-1')
 
 if __name__ == '__main__':
-    import nose
-    nose.main()
+    try:
+        import nose
+        nose.main()
+    except ImportError:
+        unittest.main()
