@@ -87,7 +87,10 @@ class Post(object):
             input_file = f
         post_file = email.message_from_file(input_file)
 
-        # First get the file's encoding
+        if 'title' not in post_file:
+            raise PostError(self.get_filename(), 'No title')
+
+        # Get the file's encoding
         self.encoding = unicode(post_file.get('encoding') or
                                 default_encoding)
         try:
