@@ -2,7 +2,6 @@ import os
 import datetime
 import logging
 import codecs
-import locale
 from shutil import copy
 
 import weblog
@@ -18,33 +17,36 @@ def _write_file(filename, encoding, content):
     finally:
         f.close()
 
-def load_post_list(path, default_encoding, default_author,
-                   filesystem_encoding=locale.getpreferredencoding()):
-    '''
-    List and load all the files ending with '.html' in the passed directory.
-    Returns a list containing ``Post`` objects created using the loaded files.
-    '''
-    post_list = set()
-    for filename in os.listdir(path):
-        if filename.endswith('.html') or filename.endswith('.txt'):
-            logging.debug('Loading %s', filename)
-            p = Post(os.path.join(path, filename),
-                     default_encoding=default_encoding,
-                     default_author=default_author,
-                     filesystem_encoding=filesystem_encoding)
-            if p in post_list:
-                logging.debug('%r is duplicated', p)
-                for duplicated_post in post_list:
-                    if duplicated_post == p:
-                        break
-                raise IOError('%s, there is already a post '
-                              'with this title and date (%s)' % \
-                              (filename, duplicated_post.get_filename()))
+def _check_duplicated(p, posts):
+    if p in posts:
+        logging.debug('%r is duplicated', p)
+        for duplicated_post in posts:
+            if duplicated_post == p:
+                break
+        raise IOError('%s, there is already a post '
+                      'with this title and date (%s)' % \
+                      (filename, duplicated_post.get_filename()))
+
+def load_posts(source_dir, config):
+    posts = set()
+    ignore_dirs = config['ignore_dirs']
+    for root, dirs, files in os.walk(source_dir):
+        # Remove ignored directories so walk doesn't visit them
+        for d in tuple(dirs):
+            if d.startswith('.') or d in ignore_dirs:
+                del dirs[dirs.index(d)]
+        for filename in files:
+            if filename.endswith('.html') or filename.endswith('.txt'):
+                logging.debug('Loading %s', filename)
+                p = Post(os.path.join(root, filename),
+                         default_encoding=config['encoding'],
+                         default_author=config['author'],
+                         filesystem_encoding=config['filesystem_encoding'])
+                _check_duplicated(p, posts)
+                posts.add(p)
             else:
-                post_list.add(p)
-        else:
-            logging.debug('Ignoring %s', filename)
-    return post_list
+                logging.debug('Ignoring %s', filename)
+    return posts
 
 def generate_post_html(post_list, output_dir, post_tmpl, config):
     for post in post_list:
@@ -89,14 +91,7 @@ def command_publish(args, options):
     env = environment(source_dir)
 
     try:
-        post_list = list(load_post_list(source_dir,
-                                        (config.get('encoding') or
-                                         locale.getpreferredencoding()),
-                                        (config.get('author') or u''),
-                                        (config.get('filesystem_encoding') or
-                                         locale.getpreferredencoding())))
-        post_list.sort()
-        post_list.reverse()
+        post_list = sorted(load_posts(source_dir, config), reverse=True)
     except (IOError, PostError), e:
         logging.error('Error while loading post files.')
         raise SystemExit(e)
